@@ -17,7 +17,7 @@ use crate::asciicast::Asciicast;
 
 pub const DEFAULT_FONT_FAMILY: &str =
     "JetBrains Mono,Fira Code,SF Mono,Menlo,Consolas,DejaVu Sans Mono,Liberation Mono";
-pub const DEFAULT_FONT_SIZE: usize = 14;
+pub const DEFAULT_FONT_SIZE: usize = 16;
 pub const DEFAULT_FPS_CAP: u8 = 30;
 pub const DEFAULT_LAST_FRAME_DURATION: f64 = 3.0;
 pub const DEFAULT_LINE_HEIGHT: f64 = 1.4;
@@ -77,6 +77,9 @@ pub enum Theme {
     Dracula,
     GithubDark,
     GithubLight,
+    Kanagawa,
+    KanagawaDragon,
+    KanagawaLight,
     Monokai,
     Nord,
     SolarizedDark,
@@ -100,6 +103,9 @@ impl TryFrom<Theme> for theme::Theme {
             Dracula => "282a36,f8f8f2,21222c,ff5555,50fa7b,f1fa8c,bd93f9,ff79c6,8be9fd,f8f8f2,6272a4,ff6e6e,69ff94,ffffa5,d6acff,ff92df,a4ffff,ffffff".parse(),
             GithubDark => "171b21,eceff4,0e1116,f97583,a2fca2,fabb72,7db4f9,c4a0f5,1f6feb,eceff4,6a737d,bf5a64,7abf7a,bf8f57,608bbf,997dbf,195cbf,b9bbbf".parse(),
             GithubLight => "eceff4,171b21,0e1116,f97583,a2fca2,fabb72,7db4f9,c4a0f5,1f6feb,eceff4,6a737d,bf5a64,7abf7a,bf8f57,608bbf,997dbf,195cbf,b9bbbf".parse(),
+            Kanagawa => "1f1f28,dcd7ba,16161d,c34043,76946a,c0a36e,7e9cd8,957fb8,6a9589,c8c093,727169,e82424,98bb6c,e6c384,7fb4ca,938aa9,7aa89f,dcd7ba".parse(),
+            KanagawaDragon => "181616,c5c9c5,0d0c0c,c4746e,8a9a7b,c4b28a,8ba4b0,a292a3,8ea4a2,c8c093,a6a69c,e46876,87a987,e6c384,7fb4ca,938aa9,7aa89f,c5c9c5".parse(),
+            KanagawaLight => "f2ecbc,545464,1f1f28,c84053,6f894e,77713f,4d699b,b35b79,597b75,545464,8a8980,d7474b,6e915f,836f4a,6693bf,624c83,5e857a,43436cg".parse(),
             Monokai => "272822,f8f8f2,272822,f92672,a6e22e,f4bf75,66d9ef,ae81ff,a1efe4,f8f8f2,75715e,f92672,a6e22e,f4bf75,66d9ef,ae81ff,a1efe4,f9f8f5".parse(),
             Nord => "2e3440,eceff4,3b4252,bf616a,a3be8c,ebcb8b,81a1c1,b48ead,88c0d0,eceff4,3b4252,bf616a,a3be8c,ebcb8b,81a1c1,b48ead,88c0d0,eceff4".parse(),
             SolarizedDark => "002b36,839496,073642,dc322f,859900,b58900,268bd2,d33682,2aa198,eee8d5,002b36,cb4b16,586e75,657b83,839496,6c71c4,93a1a1,fdf6e3".parse(),
@@ -126,6 +132,14 @@ impl Display for Theme {
 pub fn run<I: BufRead, O: Write + Send>(input: I, output: O, config: Config) -> Result<()> {
     let Asciicast { header, events, .. } = asciicast::open(input)?;
 
+    if header.term_cols == 0 || header.term_rows == 0 {
+        return Err(anyhow!(
+            "the recording has invalid terminal size: {}x{}",
+            header.term_cols,
+            header.term_rows
+        ));
+    }
+
     let terminal_size = (
         config.cols.unwrap_or(header.term_cols as usize),
         config.rows.unwrap_or(header.term_rows as usize),
