@@ -7,11 +7,7 @@ use rgb::{RGB8, RGBA8};
 use crate::theme::Theme;
 
 pub trait Renderer {
-    fn render(
-        &mut self,
-        lines: Vec<Vec<(char, avt::Pen)>>,
-        cursor: Option<(usize, usize)>,
-    ) -> ImgVec<RGBA8>;
+    fn render(&mut self, lines: Vec<avt::Line>, cursor: Option<(usize, usize)>) -> ImgVec<RGBA8>;
     fn pixel_size(&self) -> (usize, usize);
 }
 
@@ -24,7 +20,7 @@ pub struct Settings {
     pub theme: Theme,
 }
 
-pub fn resvg(settings: Settings) -> resvg::ResvgRenderer {
+pub fn resvg<'a>(settings: Settings) -> resvg::ResvgRenderer<'a> {
     resvg::ResvgRenderer::new(settings)
 }
 
@@ -36,20 +32,21 @@ struct TextAttrs {
     foreground: Option<avt::Color>,
     background: Option<avt::Color>,
     bold: bool,
+    faint: bool,
     italic: bool,
     underline: bool,
 }
 
 fn text_attrs(
-    pen: &mut avt::Pen,
+    pen: &avt::Pen,
     cursor: &Option<(usize, usize)>,
-    x: usize,
-    y: usize,
+    col: usize,
+    row: usize,
     theme: &Theme,
 ) -> TextAttrs {
     let mut foreground = pen.foreground();
     let mut background = pen.background();
-    let inverse = cursor.map_or(false, |(cx, cy)| cx == x && cy == y);
+    let inverse = cursor == &Some((col, row));
 
     if pen.is_bold() {
         if let Some(avt::Color::Indexed(n)) = foreground {
@@ -78,6 +75,7 @@ fn text_attrs(
         foreground,
         background,
         bold: pen.is_bold(),
+        faint: pen.is_faint(),
         italic: pen.is_italic(),
         underline: pen.is_underline(),
     }
